summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSimon Rettberg2023-12-14 15:13:14 +0100
committerSimon Rettberg2023-12-14 15:13:14 +0100
commit1507dc3ff7e0cf81b6220796088d48ce6045d565 (patch)
treeb5927307d87bf6e83c776a203fde606297434752
parent[SSUS] Remove choice of keeping pxelinux enabled - unsupported (diff)
downloadsetup-scripts-1507dc3ff7e0cf81b6220796088d48ce6045d565.tar.gz
setup-scripts-1507dc3ff7e0cf81b6220796088d48ce6045d565.tar.xz
setup-scripts-1507dc3ff7e0cf81b6220796088d48ce6045d565.zip
[SSPS] Rename openslx user to bwlp
-rw-r--r--satellit_installer/includes/10-script_dropper.inc8
-rw-r--r--satellit_installer/includes/50-add_users_groups.inc10
-rw-r--r--satellit_installer/static_files/system/etc/issue2
-rw-r--r--satellit_installer/static_files/system/etc/sudoers.d/openslx-overrides2
-rwxr-xr-xsatellit_installer/static_files/system/opt/openslx/firstboot.sh4
5 files changed, 13 insertions, 13 deletions
diff --git a/satellit_installer/includes/10-script_dropper.inc b/satellit_installer/includes/10-script_dropper.inc
index 11ab9b9..4bd14b2 100644
--- a/satellit_installer/includes/10-script_dropper.inc
+++ b/satellit_installer/includes/10-script_dropper.inc
@@ -1,10 +1,10 @@
fb_enable_firstrun() {
local script="/opt/openslx/firstrun.sh"
[ -x "$script" ] || perror "Firstrun script not found ($script)"
- if ! grep -qF "$script" "/home/openslx/.profile"; then
- echo "# Patching openslx's .profile"
- echo "[ -t 0 ] && $script" >> "/home/openslx/.profile"
- chown openslx:openslx "/home/openslx/.profile" "$script"
+ if ! grep -qF "$script" "/home/bwlp/.profile"; then
+ echo "# Patching bwlp's .profile"
+ echo "[ -t 0 ] && $script" >> "/home/bwlp/.profile"
+ chown bwlp:bwlp "/home/bwlp/.profile" "$script"
fi
}
diff --git a/satellit_installer/includes/50-add_users_groups.inc b/satellit_installer/includes/50-add_users_groups.inc
index e6f92f1..69b07f1 100644
--- a/satellit_installer/includes/50-add_users_groups.inc
+++ b/satellit_installer/includes/50-add_users_groups.inc
@@ -1,5 +1,5 @@
add_users_groups() {
- add_group openslx 1000
+ add_group bwlp 1000
add_group taskmanager 1001
add_group ldadp 1002
add_group vmware 1003
@@ -7,7 +7,7 @@ add_users_groups() {
add_group images 12345
# add_user: $1 username, $2 num. uid, $3 prim. (num.) gid, ($4 optional, other group)
- add_user openslx 1000 1000
+ add_user bwlp 1000 1000
add_user taskmanager 1001 1001
add_user ldadp 1002 1002
add_user_nohome vmware 1003 1003
@@ -15,9 +15,9 @@ add_users_groups() {
add_user_nohome dnbd3 10002 10002
adduser www-data adm # So the webif can read /var/log stuff
adduser dnbd3 images # Put dnbd3 user into images group so it can write the NFS share
- adduser openslx sudo # openslx is the main user, as we disallow ssh login as root
+ adduser bwlp sudo # bwlp is the main user, as we disallow ssh login as root
- echo "# disable root login, set default password for openslx"
+ echo "# disable root login, set default password for bwlp"
usermod -p "*" root
- echo "openslx:$DEFAULT_OPENSLX_PASSWORD" | chpasswd
+ echo "bwlp:$DEFAULT_OPENSLX_PASSWORD" | chpasswd || perror "Error setting default password for bwlp"
}
diff --git a/satellit_installer/static_files/system/etc/issue b/satellit_installer/static_files/system/etc/issue
index 286fcf6..2a0945d 100644
--- a/satellit_installer/static_files/system/etc/issue
+++ b/satellit_installer/static_files/system/etc/issue
@@ -2,6 +2,6 @@
bwLehrpool Satellite Server (Debian \S{VERSION_ID})
-------------------------------------------------
-Bitte loggen Sie sich als Nutzer "openslx" ein, um die
+Bitte loggen Sie sich als Nutzer "bwlp" ein, um die
Einrichtung des Systems abzuschließen.
diff --git a/satellit_installer/static_files/system/etc/sudoers.d/openslx-overrides b/satellit_installer/static_files/system/etc/sudoers.d/openslx-overrides
index 6123bfd..5cfa7d0 100644
--- a/satellit_installer/static_files/system/etc/sudoers.d/openslx-overrides
+++ b/satellit_installer/static_files/system/etc/sudoers.d/openslx-overrides
@@ -1 +1 @@
-openslx ALL=(root) NOPASSWD: /usr/local/bin/netsetup
+bwlp ALL=(root) NOPASSWD: ALL
diff --git a/satellit_installer/static_files/system/opt/openslx/firstboot.sh b/satellit_installer/static_files/system/opt/openslx/firstboot.sh
index c8a6a36..04f5e93 100755
--- a/satellit_installer/static_files/system/opt/openslx/firstboot.sh
+++ b/satellit_installer/static_files/system/opt/openslx/firstboot.sh
@@ -27,7 +27,7 @@ perror() {
if ! [ -e "$conf" ]; then
# First time this script runs, it will delete the config at the end; this
# means this has to be the second bootup, after the user finished the
# firstrun.sh script on first login as "openslx".
# Completely delete the script now, and also firstrun.sh
unlink "/opt/openslx/firstrun.sh"
unlink "/opt/openslx/firstboot.sh"
@@ -121,7 +121,7 @@ cat > /etc/motd <<THEREDOC
> *** bwLehrpool Satelliten-Server, Version $VERSION ***
> Eingerichtet am $(date)
>
-> Wenn Sie sich als 'openslx' eingeloggt haben, haben Sie nun folgende Optionen:
+> Wenn Sie sich als 'bwlp' eingeloggt haben, haben Sie nun folgende Optionen:
> netsetup - Konfiguriert das Netzwerk-Interface neu (DHCP oder statisch)
> sudo reboot - System neustarten
> sudo poweroff - System herunterfahren
@@ -27,7 +27,7 @@ perror() {
# First time this script runs, it will delete the config at the end; this
# means this has to be the second bootup, after the user finished the
- # firstrun.sh script on first login as "openslx".
+ # firstrun.sh script on first login as "bwlp".
# Completely delete the script now, and also firstrun.sh
unlink "/opt/openslx/firstrun.sh"